katsdpmodels package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   katsdpmodels.fetch

Submodules
----------

katsdpmodels.band\_mask module
------------------------------

.. automodule:: katsdpmodels.band_mask
   :members:
   :undoc-members:
   :show-inheritance:

katsdpmodels.models module
--------------------------

.. automodule:: katsdpmodels.models
   :members:
   :undoc-members:
   :show-inheritance:

katsdpmodels.rfi\_mask module
-----------------------------

.. automodule:: katsdpmodels.rfi_mask
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: katsdpmodels
   :members:
   :undoc-members:
   :show-inheritance:
